package com.smppw.analysis.client;

import com.smppw.analysis.application.service.style.StyleService;
import com.smppw.analysis.domain.dto.style.*;
import com.smppw.common.pojo.ResultVo;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Map;

/**
 * @author wangzaijun
 * @date 2023/8/7 15:52
 * @description 风格评测api
 */
@RestController
@RequestMapping("/v1/api/style")
public class FundStyleApi {
    private final StyleService service;

    public FundStyleApi(StyleService service) {
        this.service = service;
    }

    /**
     * 股票业绩归因（五因子归因分析）-前端组件：风格评测-股票业绩归因组件
     *
     * @param params 请求参数
     * @return /
     */
    @PostMapping("stock-attribution")
    public ResultVo<Map<String, Object>> stockAttribution(@RequestBody StockAttributionParams params) {
        return ResultVo.ok(this.service.stockAttribution(params));
    }

    /**
     * 债券业绩归因-前端组件：风格评测-债券业绩归因
     *
     * @param params 请求参数
     * @return /
     */
    @PostMapping("bond-attribution")
    public ResultVo<Map<String, Object>> bondAttribution(@RequestBody BondAttributionParams params) {
        return ResultVo.ok(this.service.bondAttribution(params));
    }

    /**
     * 相对价值业绩归因-前端组件：风格评测-相对价值业绩归因
     *
     * @param params 请求参数
     * @return /
     */
    @PostMapping("relative-attribution")
    public ResultVo<Map<String, Object>> relativeAttribution(@RequestBody RelativeAttributionParams params) {
        return ResultVo.ok(this.service.relativeAttribution(params));
    }

    /**
     * 成长价值风格-前端组件：风格评测-成长价值风格
     *
     * @param params 请求参数
     * @return /
     */
    @PostMapping("growth-value")
    public ResultVo<FundStyleVO> growthValue(@RequestBody GrowthValueParams params) {
        return ResultVo.ok(this.service.growthValue(params));
    }

    /**
     * 行业配置-前端组件：风格评测-行业配置
     *
     * @param params 请求参数
     * @return /
     */
    @PostMapping("industry-value")
    public ResultVo<FundStyleVO> industryValue(@RequestBody IndustryValueParams params) {
        return ResultVo.ok(this.service.industryValue(params));
    }

    /**
     * 期货风格-前端组件：风格评测-期货风格
     *
     * @param params 请求参数
     * @return /
     */
    @PostMapping("future-factor")
    public ResultVo<Map<String, Object>> futureFactor(@RequestBody FutureFactorParams params) {
        return ResultVo.ok(this.service.futureFactor(params));
    }

    /**
     * 自定义风格-前端组件：风格评测-自定义风格
     *
     * @param params 请求参数
     * @return /
     */
    @PostMapping("custom-rbsa")
    public ResultVo<CustomRbsaVO> customRbsa(@RequestBody CustomRbsaParams params) {
        return ResultVo.ok(this.service.customRbsa(params));
    }

    /**
     * Barra风格概览
     */
    @PostMapping("/barra-factor-overview")
    public ResultVo<Map<String, Object>> barraOverview(@RequestBody BarraStyleParams params) {
        return ResultVo.ok(this.service.barraOverview(params));
    }

    /**
     * Barra 风格归因
     */
    @PostMapping("/barra-factor-risk-profit")
    public ResultVo<Map<String, Object>> barraRiskProfit(@RequestBody BarraStyleParams params) {
        return ResultVo.ok((this.service.barraRiskProfit(params)));
    }

    /**
     * 选股择时能力-前端组件：风格评测-选股择时能力
     *
     * @param params 请求参数
     * @return /
     */
    @PostMapping("selection-timing")
    public ResultVo<Map<String, Object>> selectionTiming(@RequestBody SelectionTimingParams params) {
        return ResultVo.ok(this.service.selectionTiming(params));
    }

    /**
     * 融智 风格总览-前端组件：风格评测-融智 风格总览
     *
     * @param params 请求参数
     * @return /
     */
    @PostMapping("ppw")
    public ResultVo<Map<String, Object>> rzStyle(@RequestBody RzStyleParams params) {
        return ResultVo.ok(this.service.rzStyle(params));
    }
}
